@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2016-2017 Laurent Montel <montel@kde.org>
+ * Copyright (C) 2016-2018 Laurent Montel <montel@kde.org>
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -21,15 +21,14 @@
 #define QTRESOURCETEMPLATELOADER_H
 #include "grantlee/templateloader.h"
 #include "grantleetheme_export.h"
-namespace GrantleeTheme
-{
+namespace GrantleeTheme {
 class GRANTLEETHEME_EXPORT QtResourceTemplateLoader : public Grantlee::FileSystemTemplateLoader
 {
 public:
     QtResourceTemplateLoader(const QSharedPointer<Grantlee::AbstractLocalizer> localizer = QSharedPointer<Grantlee::AbstractLocalizer>());
 
-    Grantlee::Template loadByName(const QString &fileName, const Grantlee::Engine *engine) const Q_DECL_OVERRIDE;
-    bool canLoadTemplate(const QString &name) const Q_DECL_OVERRIDE;
+    Grantlee::Template loadByName(const QString &fileName, const Grantlee::Engine *engine) const override;
+    bool canLoadTemplate(const QString &name) const override;
 };
 }
 #endif // QTRESOURCETEMPLATELOADER_H
